.. spark-tests documentation master file, created by
   sphinx-quickstart on Thu Feb 17 17:51:44 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to spark-tests' documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   sql.rst
   delta.rst
   datetime.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
